@@ -2,5 +2,5 @@
 from ._buffers import Window, Group, Delay
 from ._combiners import Chain, Merge, Zip, ZipLatest
 from ._filters import Skip, SkipWhile, Filter, Changes, RateLimit
-from ._producers import Repeat
+from ._producers import Repeat, Metronome, InsertValue
 from ._refiners import Map
